@@ -1,29 +1,29 @@
 package router
 
 import (
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/bark"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/discord"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/generic"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/googlechat"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/gotify"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/ifttt"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/join"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/lark"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/logger"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/matrix"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/mattermost"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/ntfy"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/opsgenie"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/pushbullet"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/pushover"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/rocketchat"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/signal"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/slack"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/smtp"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/teams"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/telegram"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/wecom"
-	"github.com/nicholas-fedor/shoutrrr/pkg/services/zulip"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/chat/discord"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/chat/googlechat"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/chat/lark"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/chat/matrix"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/chat/mattermost"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/chat/rocketchat"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/chat/signal"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/chat/slack"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/chat/teams"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/chat/telegram"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/chat/wecom"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/chat/zulip"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/email/smtp"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/incident/opsgenie"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/push/bark"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/push/gotify"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/push/ifttt"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/push/join"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/push/ntfy"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/push/pushbullet"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/push/pushover"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/specialized/generic"
+	"github.com/nicholas-fedor/shoutrrr/pkg/services/specialized/logger"
 	"github.com/nicholas-fedor/shoutrrr/pkg/types"
 )
 
